@@ -221,7 +221,7 @@ def draw_evidence_gap_map_structure_ver(linenum=1, x_list=None, y_list=None,xbin
 def make_grid_with_categories(dataset, column_names, time_column, category_column, years=None, categories=None):
     '''Makes the grid for the plot as a pandas DataFrame.'''
     
-    grid = pandas.DataFrame()
+    grid = pd.DataFrame()
     if categories is None:
         categories = dataset[category_column].unique()
     if time_column:
